@@ -1,4 +1,5 @@
 from isd.errors import IsdError
+from isd.io import open
 from isd.record import Record
 
-__all__ = ["Record", "IsdError"]
+__all__ = ["Record", "IsdError", "open"]
